@@ -19,10 +19,10 @@
 ##
 
 APP_NAME = 'Awaitable'
-APP_VERSION = '0.2.0'
+APP_VERSION = '0.2.1'
 APP_DESCRIPTION = 'A decorator to asynchronously execute synchronous functions'
 APP_ID = 'awaitable.muflone.com'
-APP_URL = 'https://www.muflone.com/awaitable/'
+APP_URL = 'http://www.muflone.com/awaitable/'
 APP_AUTHOR = 'Fabio Castelli'
 APP_AUTHOR_EMAIL = 'muflone@muflone.com'
 APP_COPYRIGHT = 'Copyright 2022 %s' % APP_AUTHOR
